PMW3901 2-Dimensional Optical Flow Sensor
=========================================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install pmw3901``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/pmw3901-python``
-  ``cd pmw3901-python``
-  ``sudo ./install.sh``

.. |Build Status| image:: https://travis-ci.com/pimoroni/pmw3901-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/pmw3901-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/pmw3901-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/pmw3901-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/pmw3901.svg
   :target: https://pypi.python.org/pypi/pmw3901
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/pmw3901.svg
   :target: https://pypi.python.org/pypi/pmw3901
